@@ -78,6 +78,21 @@
 # define     __SAS_SHMAP_MAX         0x00000400000L   /* 4MB */
 #endif
 
+#ifdef __aarch64__
+# define     __WORDSIZE_64
+# define     __SAS_BASE_ADDRESS      0x4000000000L   /* 512GB */
+# define     RegionSize              0x2000000000L   /* 128GB */
+# define     SegmentSize             0x0010000000L   /* 256MB */
+# define     __SAS_SHMAP_MAX         0x0001000000L   /* 16MB */
+#endif
+
+#ifdef __arm__
+# define     __SAS_BASE_ADDRESS      0x60000000UL
+# define     RegionSize              0x20000000UL    /* 512MB */
+# define     SegmentSize             0x01000000UL    /*  16MB */
+# define     __SAS_SHMAP_MAX         0x01000000UL    /*  16MB */
+#endif
+
 /* 
  * If the platform is not recognized above, select some resonable default.
  */
